# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlWvLedOverhang(KeuzelijstField):
    """Afstand tot de rand van de rijbaan van de verticale projectie van het verlichtingstoestel op de rijbaan in meter. Als de afstand tot de rijbaan gelijk is aan 0, dan valt de verticale projectie samen met de rand van de rijbaan, bij negatieve waardes ligt de verticale projectie in de berm en bij positieve waardes ligt de verticale projectie op de rijbaan."""
    naam = 'KlWvLedOverhang'
    label = 'WV LED overhang'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlWvLedOverhang'
    definition = 'Afstand tot de rand van de rijbaan van de verticale projectie van het verlichtingstoestel op de rijbaan in meter. Als de afstand tot de rijbaan gelijk is aan 0, dan valt de verticale projectie samen met de rand van de rijbaan, bij negatieve waardes ligt de verticale projectie in de berm en bij positieve waardes ligt de verticale projectie op de rijbaan.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlWvLedOverhang'
    options = {
        '0': KeuzelijstWaarde(invulwaarde='0',
                              label='+0',
                              status='uitgebruik',
                              definitie='0',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/0'),
        '0-2': KeuzelijstWaarde(invulwaarde='0-2',
                                label='0',
                                status='ingebruik',
                                definitie='0-2',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/0-2'),
        '0-5': KeuzelijstWaarde(invulwaarde='0-5',
                                label='+0.5',
                                status='ingebruik',
                                definitie='0-5',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/0-5'),
        '0-5-2': KeuzelijstWaarde(invulwaarde='0-5-2',
                                  label='-0.5',
                                  status='ingebruik',
                                  definitie='0-5-2',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/0-5-2'),
        '1': KeuzelijstWaarde(invulwaarde='1',
                              label='-1',
                              status='uitgebruik',
                              definitie='-1',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/1'),
        '1-0': KeuzelijstWaarde(invulwaarde='1-0',
                                label='+1.0',
                                status='ingebruik',
                                definitie='1-0',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/1-0'),
        '1-0-2': KeuzelijstWaarde(invulwaarde='1-0-2',
                                  label='-1.0',
                                  status='ingebruik',
                                  definitie='1-0-2',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/1-0-2'),
        '1-5': KeuzelijstWaarde(invulwaarde='1-5',
                                label='+1.5',
                                status='ingebruik',
                                definitie='1-5',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/1-5'),
        '1-5-2': KeuzelijstWaarde(invulwaarde='1-5-2',
                                  label='-1.5',
                                  status='ingebruik',
                                  definitie='1-5-2',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/1-5-2'),
        '10-5': KeuzelijstWaarde(invulwaarde='10-5',
                                 label='-10.5',
                                 status='ingebruik',
                                 definitie='-10.5',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/10-5'),
        '2': KeuzelijstWaarde(invulwaarde='2',
                              label='-2',
                              status='uitgebruik',
                              definitie='-2',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/2'),
        '2-0': KeuzelijstWaarde(invulwaarde='2-0',
                                label='+2.0',
                                status='ingebruik',
                                definitie='2-0',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/2-0'),
        '2-0-2': KeuzelijstWaarde(invulwaarde='2-0-2',
                                  label='-2.0',
                                  status='ingebruik',
                                  definitie='2-0-2',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/2-0-2'),
        '2-5': KeuzelijstWaarde(invulwaarde='2-5',
                                label='+2.5',
                                status='ingebruik',
                                definitie='2-5',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/2-5'),
        '2-5-2': KeuzelijstWaarde(invulwaarde='2-5-2',
                                  label='-2.5',
                                  status='ingebruik',
                                  definitie='2-5-2',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/2-5-2'),
        '3': KeuzelijstWaarde(invulwaarde='3',
                              label='-3',
                              status='uitgebruik',
                              definitie='-3',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/3'),
        '3-0': KeuzelijstWaarde(invulwaarde='3-0',
                                label='+3.0',
                                status='ingebruik',
                                definitie='3-0',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/3-0'),
        '3-0-2': KeuzelijstWaarde(invulwaarde='3-0-2',
                                  label='-3.0',
                                  status='ingebruik',
                                  definitie='3-0-2',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/3-0-2'),
        '3-5': KeuzelijstWaarde(invulwaarde='3-5',
                                label='+3.5',
                                status='ingebruik',
                                definitie='3-5',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/3-5'),
        '3-5-2': KeuzelijstWaarde(invulwaarde='3-5-2',
                                  label='-3.5',
                                  status='ingebruik',
                                  definitie='3-5-2',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/3-5-2'),
        '4': KeuzelijstWaarde(invulwaarde='4',
                              label='-4',
                              status='ingebruik',
                              definitie='4-0-2',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/4'),
        '4-2': KeuzelijstWaarde(invulwaarde='4-2',
                                label='+4',
                                status='ingebruik',
                                definitie='4-0',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/4-2'),
        '4-5': KeuzelijstWaarde(invulwaarde='4-5',
                                label='+4.5',
                                status='ingebruik',
                                definitie='4-5',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/4-5'),
        '4-5-2': KeuzelijstWaarde(invulwaarde='4-5-2',
                                  label='-4.5',
                                  status='ingebruik',
                                  definitie='4-5-2',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/4-5-2'),
        '5': KeuzelijstWaarde(invulwaarde='5',
                              label='-5',
                              status='uitgebruik',
                              definitie='-5',
                              objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/5'),
        '5-0': KeuzelijstWaarde(invulwaarde='5-0',
                                label='+5.0',
                                status='ingebruik',
                                definitie='5-0',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/5-0'),
        '5-0-2': KeuzelijstWaarde(invulwaarde='5-0-2',
                                  label='-5.0',
                                  status='ingebruik',
                                  definitie='5-0-2',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/5-0-2'),
        '5-5': KeuzelijstWaarde(invulwaarde='5-5',
                                label='+5.5',
                                status='ingebruik',
                                definitie='5-5',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/5-5'),
        '5-5-2': KeuzelijstWaarde(invulwaarde='5-5-2',
                                  label='-5.5',
                                  status='ingebruik',
                                  definitie='5-5-2',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/5-5-2'),
        '6-0': KeuzelijstWaarde(invulwaarde='6-0',
                                label='+6.0',
                                status='ingebruik',
                                definitie='6-0',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/6-0'),
        '6-0-2': KeuzelijstWaarde(invulwaarde='6-0-2',
                                  label='-6.0',
                                  status='ingebruik',
                                  definitie='6-0-2',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/6-0-2'),
        '6-5': KeuzelijstWaarde(invulwaarde='6-5',
                                label='+6.5',
                                status='ingebruik',
                                definitie='6-5',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/6-5'),
        '6-5-2': KeuzelijstWaarde(invulwaarde='6-5-2',
                                  label='-6.5',
                                  status='ingebruik',
                                  definitie='6-5-2',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/6-5-2'),
        '7-0': KeuzelijstWaarde(invulwaarde='7-0',
                                label='+7.0',
                                status='ingebruik',
                                definitie='7-0',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/7-0'),
        '7-0-2': KeuzelijstWaarde(invulwaarde='7-0-2',
                                  label='-7.0',
                                  status='ingebruik',
                                  definitie='7-0-2',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/7-0-2'),
        '7-5': KeuzelijstWaarde(invulwaarde='7-5',
                                label='-7.5',
                                status='ingebruik',
                                definitie='-7.5',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/7-5'),
        '7-5-2': KeuzelijstWaarde(invulwaarde='7-5-2',
                                  label='+7.5',
                                  status='ingebruik',
                                  definitie='7-5-2',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/7-5-2'),
        '8-5': KeuzelijstWaarde(invulwaarde='8-5',
                                label='-8.5',
                                status='ingebruik',
                                definitie='-8.5',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/8-5'),
        '9-5': KeuzelijstWaarde(invulwaarde='9-5',
                                label='-9.5',
                                status='ingebruik',
                                definitie='-9.5',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/9-5'),
        'o+0': KeuzelijstWaarde(invulwaarde='o+0',
                                label='o+0',
                                status='uitgebruik',
                                definitie='o+0',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o+0'),
        'o+0.5': KeuzelijstWaarde(invulwaarde='o+0.5',
                                  label='o+0.5',
                                  status='uitgebruik',
                                  definitie='o+0,5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o+0.5'),
        'o+1.5': KeuzelijstWaarde(invulwaarde='o+1.5',
                                  label='o+1.5',
                                  status='uitgebruik',
                                  definitie='o+1,5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o+1.5'),
        'o+2.5': KeuzelijstWaarde(invulwaarde='o+2.5',
                                  label='o+2.5',
                                  status='uitgebruik',
                                  definitie='o+2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o+2.5'),
        'o+3.5': KeuzelijstWaarde(invulwaarde='o+3.5',
                                  label='o+3.5',
                                  status='uitgebruik',
                                  definitie='o+3,5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o+3.5'),
        'o+4.5': KeuzelijstWaarde(invulwaarde='o+4.5',
                                  label='o+4.5',
                                  status='uitgebruik',
                                  definitie='o+4,5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o+4.5'),
        'o-0-5': KeuzelijstWaarde(invulwaarde='o-0-5',
                                  label='o-0.5',
                                  status='uitgebruik',
                                  definitie='o-0.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-0-5'),
        'o-1': KeuzelijstWaarde(invulwaarde='o-1',
                                label='o-1',
                                status='uitgebruik',
                                definitie='o-1',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-1'),
        'o-1-0': KeuzelijstWaarde(invulwaarde='o-1-0',
                                  label='o+1.0',
                                  status='uitgebruik',
                                  definitie='o+1.0',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-1-0'),
        'o-1-0-2': KeuzelijstWaarde(invulwaarde='o-1-0-2',
                                    label='o-1.0',
                                    status='uitgebruik',
                                    definitie='o-1.0',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-1-0-2'),
        'o-1-5': KeuzelijstWaarde(invulwaarde='o-1-5',
                                  label='o-1.5',
                                  status='uitgebruik',
                                  definitie='o-1.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-1-5'),
        'o-2': KeuzelijstWaarde(invulwaarde='o-2',
                                label='o-2',
                                status='uitgebruik',
                                definitie='o-2',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-2'),
        'o-2-5': KeuzelijstWaarde(invulwaarde='o-2-5',
                                  label='o-2.5',
                                  status='uitgebruik',
                                  definitie='o-2.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-2-5'),
        'o-3': KeuzelijstWaarde(invulwaarde='o-3',
                                label='o-3',
                                status='uitgebruik',
                                definitie='o-3.0',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-3'),
        'o-3-0': KeuzelijstWaarde(invulwaarde='o-3-0',
                                  label='o+3.0',
                                  status='uitgebruik',
                                  definitie='o+3.0',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-3-0'),
        'o-3-0-2': KeuzelijstWaarde(invulwaarde='o-3-0-2',
                                    label='o-3.0',
                                    status='uitgebruik',
                                    definitie='o-3.0',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-3-0-2'),
        'o-3-5': KeuzelijstWaarde(invulwaarde='o-3-5',
                                  label='o-3.5',
                                  status='uitgebruik',
                                  definitie='o-3.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-3-5'),
        'o-4': KeuzelijstWaarde(invulwaarde='o-4',
                                label='o-4',
                                status='uitgebruik',
                                definitie='o-4',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-4'),
        'o-4-0': KeuzelijstWaarde(invulwaarde='o-4-0',
                                  label='o+4.0',
                                  status='uitgebruik',
                                  definitie='o+4.0',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-4-0'),
        'o-4-0-2': KeuzelijstWaarde(invulwaarde='o-4-0-2',
                                    label='o-4.0',
                                    status='uitgebruik',
                                    definitie='o-4.0',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-4-0-2'),
        'o-4-5': KeuzelijstWaarde(invulwaarde='o-4-5',
                                  label='o-4.5',
                                  status='uitgebruik',
                                  definitie='o-4.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-4-5'),
        'o-5': KeuzelijstWaarde(invulwaarde='o-5',
                                label='o-5',
                                status='uitgebruik',
                                definitie='o-5',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-5'),
        'o-5-0': KeuzelijstWaarde(invulwaarde='o-5-0',
                                  label='o+5.0',
                                  status='uitgebruik',
                                  definitie='o+5.0',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-5-0'),
        'o-5-0-2': KeuzelijstWaarde(invulwaarde='o-5-0-2',
                                    label='o-5.0',
                                    status='uitgebruik',
                                    definitie='o-5.0',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-5-0-2'),
        'o-5-5': KeuzelijstWaarde(invulwaarde='o-5-5',
                                  label='o+5.5',
                                  status='uitgebruik',
                                  definitie='o+5.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-5-5'),
        'o-5-5-2': KeuzelijstWaarde(invulwaarde='o-5-5-2',
                                    label='o-5.5',
                                    status='uitgebruik',
                                    definitie='o-5.5',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-5-5-2'),
        'o-6-0': KeuzelijstWaarde(invulwaarde='o-6-0',
                                  label='o+6.0',
                                  status='uitgebruik',
                                  definitie='o+6.0',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-6-0'),
        'o-6-0-2': KeuzelijstWaarde(invulwaarde='o-6-0-2',
                                    label='o-6.0',
                                    status='uitgebruik',
                                    definitie='o-6.0',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-6-0-2'),
        'o-6-5': KeuzelijstWaarde(invulwaarde='o-6-5',
                                  label='o+6.5',
                                  status='uitgebruik',
                                  definitie='o+6.5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-6-5'),
        'o-6-5-2': KeuzelijstWaarde(invulwaarde='o-6-5-2',
                                    label='o-6.5',
                                    status='uitgebruik',
                                    definitie='o-6.5',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-6-5-2'),
        'o-7-0': KeuzelijstWaarde(invulwaarde='o-7-0',
                                  label='o+7.0',
                                  status='uitgebruik',
                                  definitie='o+7.0',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-7-0'),
        'o-7-0-2': KeuzelijstWaarde(invulwaarde='o-7-0-2',
                                    label='o-7.0',
                                    status='uitgebruik',
                                    definitie='o-7.0',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedOverhang/o-7-0-2')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Voedingspunt import Voedingspunt
from ...Datatypes.KlEleAansluitvermogen import KlEleAansluitvermogen
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class VoedingDerdenLaagspanning(Voedingspunt, PuntGeometrie):
    """Aansluiting op het laagspanningsnet van een andere partij, niet rechtstreeks bij de distributienetbeheerder en niet afgetakt van de asset beheerder."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoedingDerdenLaagspanning'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#EnergiemeterDerden', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hoofdschakelaar', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Laagspanningsbord', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Voedt', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stroomkring', direction='o')  # o = direction: outgoing

        self._aansluitvermogen = OTLAttribuut(field=KlEleAansluitvermogen,
                                              naam='aansluitvermogen',
                                              label='aansluitvermogen',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoedingDerdenLaagspanning.aansluitvermogen',
                                              definition='Vermogen van de aansluiting.',
                                              owner=self)

    @property
    def aansluitvermogen(self) -> str:
        """Vermogen van de aansluiting."""
        return self._aansluitvermogen.get_waarde()

    @aansluitvermogen.setter
    def aansluitvermogen(self, value):
        self._aansluitvermogen.set_waarde(value, owner=self)



# coding=utf-8
from typing import List
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlDekselKaderType import KlDekselKaderType
from ...Datatypes.KlDekselKlasse import KlDekselKlasse
from ...Datatypes.KlDekselMateriaal import KlDekselMateriaal
from ...Datatypes.KlDekselRegeling import KlDekselRegeling
from ...Datatypes.KlDekselVergrendeling import KlDekselVergrendeling
from ...Datatypes.KlRioleringVorm import KlRioleringVorm
from ...Datatypes.KwantWrdInCentimeter import KwantWrdInCentimeter, KwantWrdInCentimeterWaarden
from ...Datatypes.KwantWrdInVierkanteMeter import KwantWrdInVierkanteMeter, KwantWrdInVierkanteMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Bovenbouw(AIMObject, PuntGeometrie, VlakGeometrie):
    """Een combinatie van het riooldeksel met de kader en de regeling."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bovenbouw'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    deprecated_version = '2.1.0'

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Contactpunt', direction='u', deprecated='2.1.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kamer', direction='u', deprecated='2.1.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schacht', direction='u', deprecated='2.1.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#TechnischePut', direction='u', deprecated='2.1.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#InspectieputRiolering', direction='o', deprecated='2.1.0')  # o = direction: outgoing

        self._breedte = OTLAttribuut(field=KwantWrdInCentimeter,
                                     naam='breedte',
                                     label='breedte',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bovenbouw.breedte',
                                     usagenote='Klasse uit gebruik sinds versie 2.1.0',
                                     deprecated_version='2.1.0',
                                     definition='Breedte-afmeting van het deksel in centimeter. Bij vierkante en cirkelvormige deksels is deze waarde gelijk aan de hoogte.',
                                     owner=self)

        self._dekselklasse = OTLAttribuut(field=KlDekselKlasse,
                                          naam='dekselklasse',
                                          label='dekselklasse',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bovenbouw.dekselklasse',
                                          usagenote='Klasse uit gebruik sinds versie 2.1.0',
                                          deprecated_version='2.1.0',
                                          definition='Bepaalt de mate waarin het deksel van de bovenbouw belast kan worden door voertuigen.',
                                          owner=self)

        self._dekselvorm = OTLAttribuut(field=KlRioleringVorm,
                                        naam='dekselvorm',
                                        label='dekselvorm',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bovenbouw.dekselvorm',
                                        usagenote='Klasse uit gebruik sinds versie 2.1.0',
                                        deprecated_version='2.1.0',
                                        definition='Bepaalt de vorm van het deksel.',
                                        owner=self)

        self._hoogte = OTLAttribuut(field=KwantWrdInCentimeter,
                                    naam='hoogte',
                                    label='hoogte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bovenbouw.hoogte',
                                    usagenote='Klasse uit gebruik sinds versie 2.1.0',
                                    deprecated_version='2.1.0',
                                    definition='Hoogte-afmeting van het deksel in centimeter. Bij vierkante en cirkelvormige deksels is deze waarde gelijk aan de breedte.',
                                    owner=self)

        self._isAfgesloten = OTLAttribuut(field=BooleanField,
                                          naam='isAfgesloten',
                                          label='is afgesloten',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bovenbouw.isAfgesloten',
                                          usagenote='Klasse uit gebruik sinds versie 2.1.0',
                                          deprecated_version='2.1.0',
                                          definition='Bepaling of de afsluitinrichting vergrendeld is of niet.',
                                          owner=self)

        self._isScharnierend = OTLAttribuut(field=BooleanField,
                                            naam='isScharnierend',
                                            label='is scharnierend',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bovenbouw.isScharnierend',
                                            usagenote='Klasse uit gebruik sinds versie 2.1.0',
                                            deprecated_version='2.1.0',
                                            definition='Het deksel is al of niet bevestigd met een scharnier.',
                                            owner=self)

        self._isWaterdichtVergrendeld = OTLAttribuut(field=BooleanField,
                                                     naam='isWaterdichtVergrendeld',
                                                     label='is waterdicht vergrendeld',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bovenbouw.isWaterdichtVergrendeld',
                                                     usagenote='Klasse uit gebruik sinds versie 2.1.0',
                                                     deprecated_version='2.1.0',
                                                     definition='Geeft aan of de bovenbouw al dan niet waterdicht vergrendeld is zodat het water zich niet boven de bovenbouw kan begeven.',
                                                     owner=self)

        self._kader = OTLAttribuut(field=KlDekselKaderType,
                                   naam='kader',
                                   label='kader',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bovenbouw.kader',
                                   usagenote='Klasse uit gebruik sinds versie 2.1.0',
                                   deprecated_version='2.1.0',
                                   definition='Bepaalt het type van het dekselkader.',
                                   owner=self)

        self._materiaal = OTLAttribuut(field=KlDekselMateriaal,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bovenbouw.materiaal',
                                       usagenote='Klasse uit gebruik sinds versie 2.1.0',
                                       deprecated_version='2.1.0',
                                       definition='Het materiaal waaruit het deksel van de bovenbouw is vervaardigd.',
                                       owner=self)

        self._oppervlakte = OTLAttribuut(field=KwantWrdInVierkanteMeter,
                                         naam='oppervlakte',
                                         label='oppervlakte',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bovenbouw.oppervlakte',
                                         usagenote='Klasse uit gebruik sinds versie 2.1.0',
                                         deprecated_version='2.1.0',
                                         definition='De oppervlakte van het zichtbare deel van de bovenbouw in vierkante meter.',
                                         owner=self)

        self._regeling = OTLAttribuut(field=KlDekselRegeling,
                                      naam='regeling',
                                      label='regeling',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bovenbouw.regeling',
                                      usagenote='Klasse uit gebruik sinds versie 2.1.0',
                                      deprecated_version='2.1.0',
                                      definition='De wijze hoe de regeling van het deksel is uitgevoerd.',
                                      owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bovenbouw.technischeFiche',
                                             usagenote='Klasse uit gebruik sinds versie 2.1.0 .Bestanden van het type xlsx of pdf.',
                                             deprecated_version='2.1.0',
                                             kardinaliteit_max='*',
                                             definition='De technische fiche van de bovenbouw.',
                                             owner=self)

        self._vergrendeling = OTLAttribuut(field=KlDekselVergrendeling,
                                           naam='vergrendeling',
                                           label='vergrendeling',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bovenbouw.vergrendeling',
                                           usagenote='Klasse uit gebruik sinds versie 2.1.0',
                                           deprecated_version='2.1.0',
                                           definition='Bepaalt het type sleutel voor het ontgrendelen van het deksel.',
                                           owner=self)

    @property
    def breedte(self) -> KwantWrdInCentimeterWaarden:
        """Breedte-afmeting van het deksel in centimeter. Bij vierkante en cirkelvormige deksels is deze waarde gelijk aan de hoogte."""
        return self._breedte.get_waarde()

    @breedte.setter
    def breedte(self, value):
        self._breedte.set_waarde(value, owner=self)

    @property
    def dekselklasse(self) -> str:
        """Bepaalt de mate waarin het deksel van de bovenbouw belast kan worden door voertuigen."""
        return self._dekselklasse.get_waarde()

    @dekselklasse.setter
    def dekselklasse(self, value):
        self._dekselklasse.set_waarde(value, owner=self)

    @property
    def dekselvorm(self) -> str:
        """Bepaalt de vorm van het deksel."""
        return self._dekselvorm.get_waarde()

    @dekselvorm.setter
    def dekselvorm(self, value):
        self._dekselvorm.set_waarde(value, owner=self)

    @property
    def hoogte(self) -> KwantWrdInCentimeterWaarden:
        """Hoogte-afmeting van het deksel in centimeter. Bij vierkante en cirkelvormige deksels is deze waarde gelijk aan de breedte."""
        return self._hoogte.get_waarde()

    @hoogte.setter
    def hoogte(self, value):
        self._hoogte.set_waarde(value, owner=self)

    @property
    def isAfgesloten(self) -> bool:
        """Bepaling of de afsluitinrichting vergrendeld is of niet."""
        return self._isAfgesloten.get_waarde()

    @isAfgesloten.setter
    def isAfgesloten(self, value):
        self._isAfgesloten.set_waarde(value, owner=self)

    @property
    def isScharnierend(self) -> bool:
        """Het deksel is al of niet bevestigd met een scharnier."""
        return self._isScharnierend.get_waarde()

    @isScharnierend.setter
    def isScharnierend(self, value):
        self._isScharnierend.set_waarde(value, owner=self)

    @property
    def isWaterdichtVergrendeld(self) -> bool:
        """Geeft aan of de bovenbouw al dan niet waterdicht vergrendeld is zodat het water zich niet boven de bovenbouw kan begeven."""
        return self._isWaterdichtVergrendeld.get_waarde()

    @isWaterdichtVergrendeld.setter
    def isWaterdichtVergrendeld(self, value):
        self._isWaterdichtVergrendeld.set_waarde(value, owner=self)

    @property
    def kader(self) -> str:
        """Bepaalt het type van het dekselkader."""
        return self._kader.get_waarde()

    @kader.setter
    def kader(self, value):
        self._kader.set_waarde(value, owner=self)

    @property
    def materiaal(self) -> str:
        """Het materiaal waaruit het deksel van de bovenbouw is vervaardigd."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)

    @property
    def oppervlakte(self) -> KwantWrdInVierkanteMeterWaarden:
        """De oppervlakte van het zichtbare deel van de bovenbouw in vierkante meter."""
        return self._oppervlakte.get_waarde()

    @oppervlakte.setter
    def oppervlakte(self, value):
        self._oppervlakte.set_waarde(value, owner=self)

    @property
    def regeling(self) -> str:
        """De wijze hoe de regeling van het deksel is uitgevoerd."""
        return self._regeling.get_waarde()

    @regeling.setter
    def regeling(self, value):
        self._regeling.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> List[DtcDocumentWaarden]:
        """De technische fiche van de bovenbouw."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)

    @property
    def vergrendeling(self) -> str:
        """Bepaalt het type sleutel voor het ontgrendelen van het deksel."""
        return self._vergrendeling.get_waarde()

    @vergrendeling.setter
    def vergrendeling(self, value):
        self._vergrendeling.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Hoppinzuil import Hoppinzuil
from ...Datatypes.KwantWrdInCentimeter import KwantWrdInCentimeter, KwantWrdInCentimeterWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class DigitaleHoppinzuil(Hoppinzuil):
    """Een digitale hoppinzuil is een interactieve informatiezuil die als doel heeft reizigers, al dan niet in realtime, te informeren over de vervoersmogelijkheden en diensten die op de locatie van de zuil voorhanden zijn."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DigitaleHoppinzuil'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self._schermHoogte = OTLAttribuut(field=KwantWrdInCentimeter,
                                          naam='schermHoogte',
                                          label='scherm hoogte',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DigitaleHoppinzuil.schermHoogte',
                                          definition='De afstand tussen de onderste zijde van het scherm en het maaiveld in cm.',
                                          owner=self)

    @property
    def schermHoogte(self) -> KwantWrdInCentimeterWaarden:
        """De afstand tussen de onderste zijde van het scherm en het maaiveld in cm."""
        return self._schermHoogte.get_waarde()

    @schermHoogte.setter
    def schermHoogte(self, value):
        self._schermHoogte.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Vluchtganginrichting(AIMNaamObject, VlakGeometrie):
    """Het geheel van componenten die ontworpen zijn om snel en effectief de evacuatie van mensen te faciliteren in een koker die dienst doet als vluchtgang in geval van een calamiteit."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Vluchtganginrichting'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Vluchtroute', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandblusser', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Brandhaspel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Contactpunt', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Deur', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DynamischeVluchtwegindicatie', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hulppostkast', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hydrant', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IntercomToestel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#InwendigVerlichtPictogram', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Montagekast', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Overdrukventilator', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Pictogram', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Stopcontact', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Verwarmingselement', direction='i')  # i = direction: incoming



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.LinkendElement import LinkendElement
from ...Datatypes.KlFlensType import KlFlensType
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Flens(LinkendElement, PuntGeometrie):
    """Een platte ring aan het uiteinde van een buis met als functie het mogelijk maken van het verbinden van de buis met een andere buis, wand, etc."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Flens'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Brandvoorziening', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Buis', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LinkendElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#PutRelatie', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#WaterloopRelatie', direction='i')  # i = direction: incoming

        self._type = OTLAttribuut(field=KlFlensType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Flens.type',
                                  definition='Geeft aan wat voor type deze flens is.',
                                  owner=self)

    @property
    def type(self) -> str:
        """Geeft aan wat voor type deze flens is."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
from abc import abstractmethod, ABC


# Generated with OTLClassCreator. To modify: extend, do not edit
class Toegangselement(ABC):
    """Abstracte voor het groeperen van de relaties voor elementen die toegang verschaffen tot een behuizing of locatie."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Toegangselement'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Behuizing', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Buitenkast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Gebouw', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Lokaal', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Afsluiting', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Cabine', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Contactpunt', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Container', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Doorverbinddoos', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HSCabine', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Hulppostkast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IndoorKast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Lockerkast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Magneetgrendel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Montagekast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slot', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#TechnischePut', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wegkantkast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Zelfsluiter', direction='u')  # u = unidirectional

        pass



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlOptischeWegdeksensorModelnaam(KeuzelijstField):
    """Optische wegdeksensor modelnamen."""
    naam = 'KlOptischeWegdeksensorModelnaam'
    label = 'Optische wegdeksensor modelnaam'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlOptischeWegdeksensorModelnaam'
    definition = 'Optische wegdeksensor modelnamen.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlOptischeWegdeksensorModelnaam'
    options = {
        'dsc111': KeuzelijstWaarde(invulwaarde='dsc111',
                                   label='DSC111',
                                   status='ingebruik',
                                   definitie='DSC111',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlOptischeWegdeksensorModelnaam/dsc111'),
        'dsc211': KeuzelijstWaarde(invulwaarde='dsc211',
                                   label='DSC211',
                                   status='ingebruik',
                                   definitie='DSC211',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlOptischeWegdeksensorModelnaam/dsc211'),
        'dst111': KeuzelijstWaarde(invulwaarde='dst111',
                                   label='DST111',
                                   status='ingebruik',
                                   definitie='DST111',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlOptischeWegdeksensorModelnaam/dst111')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from typing import List
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from otlmow_model.OtlmowModel.BaseClasses.WaardenObject import WaardenObject
from otlmow_model.OtlmowModel.BaseClasses.ComplexField import ComplexField
from ..Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ..Datatypes.DteTekstblok import DteTekstblok, DteTekstblokWaarden
from ..Datatypes.KlToegangsprocedureBijlageType import KlToegangsprocedureBijlageType
from otlmow_model.OtlmowModel.BaseClasses.URIField import URIField


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcToegangsprocedureBijlageWaarden(WaardenObject):
    def __init__(self):
        WaardenObject.__init__(self)
        self._document = OTLAttribuut(field=DtcDocument,
                                      naam='document',
                                      label='document',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcToegangsprocedureBijlage.document',
                                      kardinaliteit_max='*',
                                      definition='Document dat bij de toegangsprocedure als bijlage toegevoed kan worden.',
                                      owner=self)

        self._nota = OTLAttribuut(field=DteTekstblok,
                                  naam='nota',
                                  label='nota',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcToegangsprocedureBijlage.nota',
                                  definition='Vrije nota die als bijlage bij de toegangsprocedure gevoegd kan worden.',
                                  owner=self)

        self._type = OTLAttribuut(field=KlToegangsprocedureBijlageType,
                                  naam='type',
                                  label='bijlage type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcToegangsprocedureBijlage.type',
                                  definition='Het type bijlage gevoegd bij de toegangsprocedure.',
                                  owner=self)

        self._website = OTLAttribuut(field=URIField,
                                     naam='website',
                                     label='website URL',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcToegangsprocedureBijlage.website',
                                     definition='Website URL die als bijlage bij de toegangsprocedure gevoegd kan worden',
                                     owner=self)

    @property
    def document(self) -> List[DtcDocumentWaarden]:
        """Document dat bij de toegangsprocedure als bijlage toegevoed kan worden."""
        return self._document.get_waarde()

    @document.setter
    def document(self, value):
        self._document.set_waarde(value, owner=self._parent)

    @property
    def nota(self) -> DteTekstblokWaarden:
        """Vrije nota die als bijlage bij de toegangsprocedure gevoegd kan worden."""
        return self._nota.get_waarde()

    @nota.setter
    def nota(self, value):
        self._nota.set_waarde(value, owner=self._parent)

    @property
    def type(self) -> str:
        """Het type bijlage gevoegd bij de toegangsprocedure."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self._parent)

    @property
    def website(self) -> str:
        """Website URL die als bijlage bij de toegangsprocedure gevoegd kan worden"""
        return self._website.get_waarde()

    @website.setter
    def website(self, value):
        self._website.set_waarde(value, owner=self._parent)


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcToegangsprocedureBijlage(ComplexField):
    """Complex datatype dat informatie omtrent een bijlage voor een toegangsprocedure specifieert."""
    naam = 'DtcToegangsprocedureBijlage'
    label = 'Bijlage toegangsprocedure'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#DtcToegangsprocedureBijlage'
    definition = 'Complex datatype dat informatie omtrent een bijlage voor een toegangsprocedure specifieert.'
    waardeObject = DtcToegangsprocedureBijlageWaarden

    def __str__(self):
        return ComplexField.__str__(self)




# coding=utf-8
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Paalmatras(AIMNaamObject, VlakGeometrie):
    """Een funderingsconstructie die wordt gebruikt op slappe bodems, voornamelijk bij de aanleg van wegen en andere infrastructuur. Het combineert (funderings)palen met een dragende matras van gewapend geokunststof en grofkorrelig materiaal, om belastingen efficiënt naar de dieper gelegen stabiele grondlagen over te brengen. De palen dragen de matras, die op zijn beurt de belasting verdeelt en overdraagt aan de palen. Deze aanpak minimaliseert zettingen en verbetert de stabiliteit van de constructie."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Paalmatras'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Funderingspaal', direction='i')  # i = direction: incoming



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from ...Datatypes.KlTypeBeschoeiing import KlTypeBeschoeiing
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class KringsBerliner(AIMObject, LijnGeometrie):
    """Een grond- en/of waterkerende constructie, die bestaat uit een verticaal in de grond geplaatste wand."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KringsBerliner'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bouwput', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sleuf', direction='u')  # u = unidirectional

        self._beschoeiingsLengte = OTLAttribuut(field=KwantWrdInMeter,
                                                naam='beschoeiingsLengte',
                                                label='beschoeiingslengte',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KringsBerliner.beschoeiingsLengte',
                                                definition='De totale lengte van de beschoeiing langs de sleuf in lopende meter.',
                                                owner=self)

        self._buisdiepte = OTLAttribuut(field=KwantWrdInMeter,
                                        naam='buisdiepte',
                                        label='buisdiepte',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KringsBerliner.buisdiepte',
                                        definition='De diepte van de buis.',
                                        owner=self)

        self._type = OTLAttribuut(field=KlTypeBeschoeiing,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KringsBerliner.type',
                                  definition='Het type beschoeiing.',
                                  owner=self)

    @property
    def beschoeiingsLengte(self) -> KwantWrdInMeterWaarden:
        """De totale lengte van de beschoeiing langs de sleuf in lopende meter."""
        return self._beschoeiingsLengte.get_waarde()

    @beschoeiingsLengte.setter
    def beschoeiingsLengte(self, value):
        self._beschoeiingsLengte.set_waarde(value, owner=self)

    @property
    def buisdiepte(self) -> KwantWrdInMeterWaarden:
        """De diepte van de buis."""
        return self._buisdiepte.get_waarde()

    @buisdiepte.setter
    def buisdiepte(self, value):
        self._buisdiepte.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Het type beschoeiing."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlLEKantopsluitingKleur(KeuzelijstField):
    """De kleur van de kantopsluiting."""
    naam = 'KlLEKantopsluitingKleur'
    label = 'Kantopsluiting kleur'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlLEKantopsluitingKleur'
    definition = 'De kleur van de kantopsluiting.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlLEKantopsluitingKleur'
    options = {
        'gekleurd': KeuzelijstWaarde(invulwaarde='gekleurd',
                                     label='gekleurd',
                                     status='ingebruik',
                                     definitie='gekleurd',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingKleur/gekleurd'),
        'grijs': KeuzelijstWaarde(invulwaarde='grijs',
                                  label='grijs',
                                  status='ingebruik',
                                  definitie='grijs',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingKleur/grijs'),
        'oker': KeuzelijstWaarde(invulwaarde='oker',
                                 label='oker',
                                 status='ingebruik',
                                 definitie='oker',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingKleur/oker'),
        'rood': KeuzelijstWaarde(invulwaarde='rood',
                                 label='rood',
                                 status='ingebruik',
                                 definitie='rood',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingKleur/rood'),
        'wit': KeuzelijstWaarde(invulwaarde='wit',
                                label='wit',
                                status='ingebruik',
                                definitie='wit',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingKleur/wit'),
        'zwart': KeuzelijstWaarde(invulwaarde='zwart',
                                  label='zwart',
                                  status='ingebruik',
                                  definitie='zwart',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlLEKantopsluitingKleur/zwart')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlPlaatsingsmethodeTWC(KeuzelijstField):
    """De mogelijke manieren of methodes om een tijdelijke waterkerende constrcutie te plaatsen."""
    naam = 'KlPlaatsingsmethodeTWC'
    label = 'Plaatsingsmethode TWC'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#KlPlaatsingsmethodeTWC'
    definition = 'De mogelijke manieren of methodes om een tijdelijke waterkerende constrcutie te plaatsen.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlPlaatsingsmethodeTWC'
    options = {
        'invaren': KeuzelijstWaarde(invulwaarde='invaren',
                                    label='invaren',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPlaatsingsmethodeTWC/invaren'),
        'plaatsen-met-kraan': KeuzelijstWaarde(invulwaarde='plaatsen-met-kraan',
                                               label='plaatsen met kraan',
                                               status='ingebruik',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPlaatsingsmethodeTWC/plaatsen-met-kraan')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from ...Classes.Abstracten.Ophanging import Ophanging
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject


# Generated with OTLClassCreator. To modify: extend, do not edit
class Schommeljuk(Ophanging, AIMNaamObject):
    """Een schommeljuk, ook wel cardan genoemd, laat een kanteling toe langs twee loodrecht op elkaar staande assen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Schommeljuk'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Lager', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Ankerplaat', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Portiek', direction='u')  # u = unidirectional



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.AxiaalDraagvermogen import AxiaalDraagvermogen
from ...Classes.Abstracten.AxiaalDraagvermogenWand import AxiaalDraagvermogenWand
from ...Classes.Abstracten.Grondkeringen import Grondkeringen
from ...Classes.Abstracten.WaterremmendeFunctie import WaterremmendeFunctie
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Funderingswand(AxiaalDraagvermogen, AxiaalDraagvermogenWand, Grondkeringen, WaterremmendeFunctie, AIMNaamObject):
    """Wand die dient om de belastingen van constructies/elementen op te vangen/over te brengen naar draagkrachtige lagen. Kan ook een grondkerende/waterkerende functie hebben."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Funderingswand'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BalkGK', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Grondanker', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AfmetingenDiepCBWand', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Grondanker', direction='i')  # i = direction: incoming

        self._totaleLengteFunderingswand = OTLAttribuut(field=KwantWrdInMeter,
                                                        naam='totaleLengteFunderingswand',
                                                        label='totale lengte funderingswand',
                                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Funderingswand.totaleLengteFunderingswand',
                                                        definition='De totale horizontale lengte van de gehele funderingswand in lopende meter.',
                                                        owner=self)

    @property
    def totaleLengteFunderingswand(self) -> KwantWrdInMeterWaarden:
        """De totale horizontale lengte van de gehele funderingswand in lopende meter."""
        return self._totaleLengteFunderingswand.get_waarde()

    @totaleLengteFunderingswand.setter
    def totaleLengteFunderingswand(self, value):
        self._totaleLengteFunderingswand.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlMateriaalDeklaag import KlMateriaalDeklaag
from ...Datatypes.KlMateriaalTaatsmechanisme import KlMateriaalTaatsmechanisme
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Taatspen(TechnischDocument, AIMNaamObject, PuntGeometrie):
    """Een onderdeel dat de verbinding maakt tussen de taatsschoen en taatspot binnen het taatsmechanisme."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Taatspen'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Taatspot', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Taatsmechanisme', direction='o')  # o = direction: outgoing

        self._heeftHouder = OTLAttribuut(field=BooleanField,
                                         naam='heeftHouder',
                                         label='heeft houder',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Taatspen.heeftHouder',
                                         definition='Geeft aan of de taatspen een houder heeft of niet.',
                                         owner=self)

        self._materiaalDeklaag = OTLAttribuut(field=KlMateriaalDeklaag,
                                              naam='materiaalDeklaag',
                                              label='materiaal deklaag',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Taatspen.materiaalDeklaag',
                                              definition='Het materiaal van het deklaag',
                                              owner=self)

        self._materiaalTaatspen = OTLAttribuut(field=KlMateriaalTaatsmechanisme,
                                               naam='materiaalTaatspen',
                                               label='materiaal taatspen',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Taatspen.materiaalTaatspen',
                                               definition='Het materiaal van de taatspen.',
                                               owner=self)

    @property
    def heeftHouder(self) -> bool:
        """Geeft aan of de taatspen een houder heeft of niet."""
        return self._heeftHouder.get_waarde()

    @heeftHouder.setter
    def heeftHouder(self, value):
        self._heeftHouder.set_waarde(value, owner=self)

    @property
    def materiaalDeklaag(self) -> str:
        """Het materiaal van het deklaag"""
        return self._materiaalDeklaag.get_waarde()

    @materiaalDeklaag.setter
    def materiaalDeklaag(self, value):
        self._materiaalDeklaag.set_waarde(value, owner=self)

    @property
    def materiaalTaatspen(self) -> str:
        """Het materiaal van de taatspen."""
        return self._materiaalTaatspen.get_waarde()

    @materiaalTaatspen.setter
    def materiaalTaatspen(self, value):
        self._materiaalTaatspen.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Onderstel(AIMNaamObject, PuntGeometrie):
    """Een onderstel, voetstuk, chassis of steunstoel is een deel van een installatie en dient als basis om onderdelen op te bevestigen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Onderstel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#DrogePompkelder', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Pompkamer', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Dompelpomp', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Elektromotor', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Pomphuis', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Riemspanner', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tandwielkast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Werkschakelaar', direction='u')  # u = unidirectional



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod
from ...Datatypes.KwantWrdInMeterTAW import KwantWrdInMeterTAW, KwantWrdInMeterTAWWaarden
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class OntwerpwaterstandStreefpeil(VlakGeometrie):
    """Abstracte om de streefpeilen en relevante ontwerpwaterstanden (afwaarts & opwaarts) van sluizen en stuwen te bundelen"""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#OntwerpwaterstandStreefpeil'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self._relevanteOntwerpWaterstandAfwaarts = OTLAttribuut(field=StringField,
                                                                naam='relevanteOntwerpWaterstandAfwaarts',
                                                                label='relevante ontwerpwaterstand afwaarts',
                                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#OntwerpwaterstandStreefpeil.relevanteOntwerpWaterstandAfwaarts',
                                                                definition='De relevante ontwerpwaterstand afwaarts van de waterbouwkundige constructie.',
                                                                owner=self)

        self._relevanteOntwerpWaterstandOpwaarts = OTLAttribuut(field=StringField,
                                                                naam='relevanteOntwerpWaterstandOpwaarts',
                                                                label='relevante ontwerpwaterstand opwaarts',
                                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#OntwerpwaterstandStreefpeil.relevanteOntwerpWaterstandOpwaarts',
                                                                definition='De relevante ontwerpwaterstand opwaarts van de waterbouwkundige constructie.',
                                                                owner=self)

        self._streefpeilAfwaarts = OTLAttribuut(field=KwantWrdInMeterTAW,
                                                naam='streefpeilAfwaarts',
                                                label='streefpeil afwaarts',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#OntwerpwaterstandStreefpeil.streefpeilAfwaarts',
                                                definition='Het gewenste waterpeil dat wordt nagestreefd aan de stroomafwaartse kant van het sluizen en/of stuwencomplex.',
                                                owner=self)

        self._streefpeilOpwaarts = OTLAttribuut(field=KwantWrdInMeterTAW,
                                                naam='streefpeilOpwaarts',
                                                label='streefpeil opwaarts',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#OntwerpwaterstandStreefpeil.streefpeilOpwaarts',
                                                definition='Het gewenste waterpeil dat wordt nagestreefd aan de stroomopwaartse kant van het sluizen en/of stuwencomplex.',
                                                owner=self)

    @property
    def relevanteOntwerpWaterstandAfwaarts(self) -> str:
        """De relevante ontwerpwaterstand afwaarts van de waterbouwkundige constructie."""
        return self._relevanteOntwerpWaterstandAfwaarts.get_waarde()

    @relevanteOntwerpWaterstandAfwaarts.setter
    def relevanteOntwerpWaterstandAfwaarts(self, value):
        self._relevanteOntwerpWaterstandAfwaarts.set_waarde(value, owner=self)

    @property
    def relevanteOntwerpWaterstandOpwaarts(self) -> str:
        """De relevante ontwerpwaterstand opwaarts van de waterbouwkundige constructie."""
        return self._relevanteOntwerpWaterstandOpwaarts.get_waarde()

    @relevanteOntwerpWaterstandOpwaarts.setter
    def relevanteOntwerpWaterstandOpwaarts(self, value):
        self._relevanteOntwerpWaterstandOpwaarts.set_waarde(value, owner=self)

    @property
    def streefpeilAfwaarts(self) -> KwantWrdInMeterTAWWaarden:
        """Het gewenste waterpeil dat wordt nagestreefd aan de stroomafwaartse kant van het sluizen en/of stuwencomplex."""
        return self._streefpeilAfwaarts.get_waarde()

    @streefpeilAfwaarts.setter
    def streefpeilAfwaarts(self, value):
        self._streefpeilAfwaarts.set_waarde(value, owner=self)

    @property
    def streefpeilOpwaarts(self) -> KwantWrdInMeterTAWWaarden:
        """Het gewenste waterpeil dat wordt nagestreefd aan de stroomopwaartse kant van het sluizen en/of stuwencomplex."""
        return self._streefpeilOpwaarts.get_waarde()

    @streefpeilOpwaarts.setter
    def streefpeilOpwaarts(self, value):
        self._streefpeilOpwaarts.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.Abstracten.AanhorigheidKoker import AanhorigheidKoker
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Trappentoren(AanhorigheidKoker, AIMNaamObject, VlakGeometrie):
    """Een trappentoren is een geïntegreerde constructie van trappen die kan dienen om 1 of meerdere niveaus te beklimmen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Trappentoren'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    deprecated_version = '2.12.0'

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kokerruimte', direction='u', deprecated='2.12.0')  # u = unidirectional



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.WaterloopRelatie import WaterloopRelatie
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlGrachtFunctie import KlGrachtFunctie
from ...Datatypes.KlGrachtdoorsnede import KlGrachtdoorsnede


# Generated with OTLClassCreator. To modify: extend, do not edit
class Gracht(WaterloopRelatie):
    """Een kunstmatige aangelegde waterloop."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Gracht'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HeeftAanvullendeGeometrie', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#AanvullendeMiddellijn', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Rioleringsstelsel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Buis', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LinkendElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#PutRelatie', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#WaterloopRelatie', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#OpenInfiltratievoorziening', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Spaarbekken', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#OpenInfiltratievoorziening', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Spaarbekken', direction='i')  # i = direction: incoming

        self._doorsnede = OTLAttribuut(field=KlGrachtdoorsnede,
                                       naam='doorsnede',
                                       label='doorsnede',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Gracht.doorsnede',
                                       definition='De doorsnede van de gracht.',
                                       owner=self)

        self._functie = OTLAttribuut(field=KlGrachtFunctie,
                                     naam='functie',
                                     label='functie',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Gracht.functie',
                                     definition='De functiebepaling van de gracht, als vesting, polder,...',
                                     owner=self)

        self._isBekleed = OTLAttribuut(field=BooleanField,
                                       naam='isBekleed',
                                       label='is bekleed',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Gracht.isBekleed',
                                       definition='Geeft aan of de oever en/of bodem van de gracht is voorzien van een kunstmatige bekleding (zoals beton, metselwerk, of kunststof), met het doel om de gracht te verstevigen, erosie te voorkomen, of het onderhoud te vergemakkelijken.',
                                       owner=self)

    @property
    def doorsnede(self) -> str:
        """De doorsnede van de gracht."""
        return self._doorsnede.get_waarde()

    @doorsnede.setter
    def doorsnede(self, value):
        self._doorsnede.set_waarde(value, owner=self)

    @property
    def functie(self) -> str:
        """De functiebepaling van de gracht, als vesting, polder,..."""
        return self._functie.get_waarde()

    @functie.setter
    def functie(self, value):
        self._functie.set_waarde(value, owner=self)

    @property
    def isBekleed(self) -> bool:
        """Geeft aan of de oever en/of bodem van de gracht is voorzien van een kunstmatige bekleding (zoals beton, metselwerk, of kunststof), met het doel om de gracht te verstevigen, erosie te voorkomen, of het onderhoud te vergemakkelijken."""
        return self._isBekleed.get_waarde()

    @isBekleed.setter
    def isBekleed(self, value):
        self._isBekleed.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from otlmow_model.OtlmowModel.BaseClasses.WaardenObject import WaardenObject
from otlmow_model.OtlmowModel.BaseClasses.ComplexField import ComplexField
from ..Datatypes.KwantWrdInCentimeter import KwantWrdInCentimeter, KwantWrdInCentimeterWaarden


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcMinMaxHoogteSchermelementWaarden(WaardenObject):
    def __init__(self):
        WaardenObject.__init__(self)
        self._maxSchermhoogte = OTLAttribuut(field=KwantWrdInCentimeter,
                                             naam='maxSchermhoogte',
                                             label='maximale schermhoogte',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#DtcMinMaxHoogteSchermelement.maxSchermhoogte',
                                             definition='De waarde die de hoogte in centimeter weergeeft van het hoogste element in de constructie.',
                                             owner=self)

        self._minSchermhoogte = OTLAttribuut(field=KwantWrdInCentimeter,
                                             naam='minSchermhoogte',
                                             label='minimale schermhoogte',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#DtcMinMaxHoogteSchermelement.minSchermhoogte',
                                             definition='De waarde die de hoogte in centimeter weergeeft van het laagste element in de constructie.',
                                             owner=self)

    @property
    def maxSchermhoogte(self) -> KwantWrdInCentimeterWaarden:
        """De waarde die de hoogte in centimeter weergeeft van het hoogste element in de constructie."""
        return self._maxSchermhoogte.get_waarde()

    @maxSchermhoogte.setter
    def maxSchermhoogte(self, value):
        self._maxSchermhoogte.set_waarde(value, owner=self._parent)

    @property
    def minSchermhoogte(self) -> KwantWrdInCentimeterWaarden:
        """De waarde die de hoogte in centimeter weergeeft van het laagste element in de constructie."""
        return self._minSchermhoogte.get_waarde()

    @minSchermhoogte.setter
    def minSchermhoogte(self, value):
        self._minSchermhoogte.set_waarde(value, owner=self._parent)


# Generated with OTLComplexDatatypeCreator. To modify: extend, do not edit
class DtcMinMaxHoogteSchermelement(ComplexField):
    """Complex datatype voor de hoogte in centimeter van het laagste element en van het hoogste element."""
    naam = 'DtcMinMaxHoogteSchermelement'
    label = 'min max hoogte schermelement'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#DtcMinMaxHoogteSchermelement'
    definition = 'Complex datatype voor de hoogte in centimeter van het laagste element en van het hoogste element.'
    waardeObject = DtcMinMaxHoogteSchermelementWaarden

    def __str__(self):
        return ComplexField.__str__(self)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KlKabelmofType import KlKabelmofType
from ...Datatypes.KlKabelmofVerbinding import KlKabelmofVerbinding
from ...Datatypes.KlNetwerkType import KlNetwerkType
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Kabelmof(AIMNaamObject, PuntGeometrie):
    """Een verbindingsgreep die aansluitingen van kabels rondom afsluit."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kabelmof'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kabel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Aardingskabel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#TechnischePut', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#DynBordGroep', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hulppost', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#MIVMeetpunt', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#MIVModule', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Z30Groep', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Camera', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DynBordVMS', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SelNietSelLus', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LoopTerminationAndProtection', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#MIVLus', direction='u')  # u = unidirectional

        self._netwerktype = OTLAttribuut(field=KlNetwerkType,
                                         naam='netwerktype',
                                         label='netwerktype',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kabelmof.netwerktype',
                                         definition='Geeft aan bij welk type nutsvoorzieningennet de kabelmof hoort volgens de types uit IMKL en Inspire.',
                                         owner=self)

        self._type = OTLAttribuut(field=KlKabelmofType,
                                  naam='type',
                                  label='type kabelmof',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kabelmof.type',
                                  definition='Soort mof volgens een lijst van types.',
                                  owner=self)

        self._verbindingstype = OTLAttribuut(field=KlKabelmofVerbinding,
                                             naam='verbindingstype',
                                             label='verbindingstype',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kabelmof.verbindingstype',
                                             definition='Geeft het type aansluiting in de mof aan.',
                                             owner=self)

    @property
    def netwerktype(self) -> str:
        """Geeft aan bij welk type nutsvoorzieningennet de kabelmof hoort volgens de types uit IMKL en Inspire."""
        return self._netwerktype.get_waarde()

    @netwerktype.setter
    def netwerktype(self, value):
        self._netwerktype.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Soort mof volgens een lijst van types."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)

    @property
    def verbindingstype(self) -> str:
        """Geeft het type aansluiting in de mof aan."""
        return self._verbindingstype.get_waarde()

    @verbindingstype.setter
    def verbindingstype(self, value):
        self._verbindingstype.set_waarde(value, owner=self)
